/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "WSIF" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2001, 2002, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package inout.wsiftypes;

import inout.wsifservice.Inout;
import java.util.Date;
import java.util.Hashtable;
import java.util.Iterator;

import util.AddressUtility;

import addressbook.wsiftypes.Address;
import addressbook.wsiftypes.Phone;

/**
 * Inout service used by InoutTest for various miscelleanous tests.
 * @author Mark Whitlock
 */
public class InoutImpl implements Inout {
    private Hashtable name2AddressTable = new Hashtable();

    public InoutImpl() {
        addEntry(
            "John B. Good",
            new Address(
                123,
                "Main Street",
                "Anytown",
                "NY",
                12345,
                new Phone(123, "456", "7890")));
        addEntry(
            "Bob Q. Public",
            new Address(
                456,
                "North Whatever",
                "Notown",
                "ME",
                12424,
                new Phone(987, "444", "5566")));
    }

    public void addEntry(String name, Address address) {
        if (name != null && address != null)
            name2AddressTable.put(name, address);
    }

    public void addEntry(String firstName, String lastName, Address address) {
        if (firstName != null && lastName != null && address != null)
            name2AddressTable.put(firstName + " " + lastName, address);
    }

    public Address getAddressFromName(String name)
        throws IllegalArgumentException {
        if (name == null)
            return null;
        return getAddressFromName(new Mutablestring(name));
    }

    public Address getAddressFromName(Mutablestring name)
        throws IllegalArgumentException {
        if (name == null)
            return null;

        String found = null;
        int star = name.toString().indexOf("*");
        if (star != -1) {
            String trimmed = name.toString().substring(0, star);
            Iterator it = name2AddressTable.keySet().iterator();
            while (it.hasNext()) {
                String key = (String) it.next();
                if (key.startsWith(trimmed)) {
                    found = key;
                    break;
                }
            }

            if (found == null)
                throw new IllegalArgumentException(
                    "Couldn't find " + name + " trimmed=" + trimmed);
        } else
            found = name.toString();

        return (Address) name2AddressTable.get(found);
    }

    public boolean getAddressFromName(Mutablestring name, Address addr)
        throws IllegalArgumentException {
        Address newAddr = getAddressFromName(name);
        if (newAddr == null)
            return false;
        AddressUtility addrUtil = new AddressUtility(newAddr);
        addrUtil.copy(addr);
        return true;
    }

    public int addNumbers(int[] nums) {
        int result = 0;
        for (int i = 0; i < nums.length; i++)
            result += nums[i];
        return result;
    }

    public Date getDate() {
        return new Date();
    }

    public String whoami(String s) {
        return new String("String");
    }
    public String whoami(float f) {
        return new String("float");
    }
    public String whoami(int i) {
        return new String("int");
    }
    public String whoami(Address a) {
        return new String("Address");
    }
}
