/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "WSIF" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 2001, 2002, International
 * Business Machines, Inc., http://www.apache.org.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package wsdl;

import javax.xml.namespace.QName;

import junit.framework.*;

public class QNameTest extends TestCase {

    public static void main(String[] args) {
        junit.textui.TestRunner.run(suite());
    }

    public static Test suite() {
        return new TestSuite(QNameTest.class);
    }

    public QNameTest(String name) {
        super(name);
    }

    /**
     * Tests the Java binding for the shopping cart scenario via WSDL
     */
    public void testEquals() throws Exception {
    	String base = "http://schemas.xmlsoap.org/wsdl/";
		QName qn1 = new QName("http://schemas.xmlsoap.org/wsdl/java/", "java");
		assertTrue("One instance is the same as itself", qn1.equals(qn1));
		QName qn2 = new QName("http://schemas.xmlsoap.org/wsdl/java/", "java");
		assertTrue("Two equivalent instances are equal qn1=qn2", qn1.equals(qn2));
		assertTrue("Two equivalent instances are equal qn2=qn1", qn2.equals(qn1));

		QName qn3 = new QName("http://ibm.com/","java");
		assertTrue("Different URI: instances are not equal qn3!=qn1", !qn3.equals(qn1));
		assertTrue("Different URI: instances are not equal qn1!=qn3", !qn1.equals(qn3));

		QName qn4 = new QName("http://schemas.xmlsoap.org/wsdl/java/", "soap");
		assertTrue("Different name: instances are not equal qn4!=qn1", !qn4.equals(qn1));
		assertTrue("Different name: instances are not equal qn1!=qn4", !qn1.equals(qn4));
		
		QName qn5 = new QName("http://schemas.xmlsoap.org/wsdl/java", "java");
		assertTrue("URI: No trailing / same as trailing slash URI", qn5.equals(qn1));
		assertTrue("URI: No trailing / same as trailing slash URI", qn1.equals(qn5));
		
    }
}
